@@ -1,6 +1,6 @@
 /*
- * pam_oath.c - a PAM module for OATH one-time passwords
- * Copyright (C) 2009-2011 Simon Josefsson
+ * test-pam_oath.c - self-tests for PAM module for OATH one-time passwords
+ * Copyright (C) 2009-2012 Simon Josefsson
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -23,7 +23,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <security/pam_appl.h>
+/* pam_sm_authenticate */
+#define PAM_SM_AUTH
+#include <security/pam_modules.h>
 
 int
 main (int argc, char **argv)
@@ -31,7 +33,7 @@ main (int argc, char **argv)
   pam_handle_t *pamh = NULL;
   int rc;
 
-  rc = pam_sm_authenticate (pamh, 0, 1, argv);
+  rc = pam_sm_authenticate (pamh, 0, 1, (const char **) argv);
 
   printf ("rc %d\n", rc);
 
